@@ -44,12 +44,12 @@ public:
         kpCommandEnvironment *environ);
     virtual ~kpEffectClearCommand ();
 
-    virtual QString name () const;
+    QString name () const Q_DECL_OVERRIDE;
 
-    virtual SizeType size () const;
+    SizeType size () const Q_DECL_OVERRIDE;
 
-    virtual void execute ();
-    virtual void unexecute ();
+    void execute () Q_DECL_OVERRIDE;
+    void unexecute () Q_DECL_OVERRIDE;
 
 private:
     bool m_actOnSelection;
