@@ -35,13 +35,12 @@
 #include "kpDefs.h"
 #include "document/kpDocument.h"
 #include "imagelib/kpImage.h"
-#include "pixmapfx/kpPixmapFX.h"
-
 #include "kpLogCategories.h"
-#include <klocale.h>
 
 #include <qapplication.h>
 
+#include <KLocalizedString>
+
 //---------------------------------------------------------------------
 
 struct kpToolFloodFillCommandPrivate
