@@ -42,7 +42,7 @@
 #include "views/kpView.h"
 #include "views/manager/kpViewManager.h"
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 #include <klocale.h>
 
 #include <qapplication.h>
@@ -96,7 +96,7 @@ void kpToolSelectionCreateCommand::setFromSelection (const kpAbstractSelection &
 void kpToolSelectionCreateCommand::execute ()
 {
 #if DEBUG_KP_TOOL_SELECTION
-    kDebug () << "kpToolSelectionCreateCommand::execute()";
+    qCDebug(kpLogCommands) << "kpToolSelectionCreateCommand::execute()";
 #endif
 
     kpDocument *doc = document ();
@@ -105,8 +105,8 @@ void kpToolSelectionCreateCommand::execute ()
     if (m_fromSelection)
     {
     #if DEBUG_KP_TOOL_SELECTION
-        kDebug () << "\tusing fromSelection";
-        kDebug () << "\t\thave sel=" << doc->selection ()
+        qCDebug(kpLogCommands) << "\tusing fromSelection";
+        qCDebug(kpLogCommands) << "\t\thave sel=" << doc->selection ()
                    << endl;
     #endif
         kpAbstractImageSelection *imageSel =
