@@ -35,7 +35,7 @@
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KDebug>
+#include "kpLogCategories.h"
 
 #include <QAbstractItemView>
 #include <QDialogButtonBox>
@@ -559,7 +559,7 @@ bool kpDocumentMetaInfoDialog::isFieldsRowDeleteable (int row) const
 void kpDocumentMetaInfoDialog::fieldsDeleteRow (int r)
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::fieldsDeleteRow("
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::fieldsDeleteRow("
               << "row=" << r << ")"
               << " currentRow=" << d->fieldsTableWidget->currentRow () << endl;
 #endif
@@ -571,19 +571,19 @@ void kpDocumentMetaInfoDialog::fieldsDeleteRow (int r)
         // Assertion follows from previous assertion.
         const int newRow = r + 1;
     #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-        kDebug () << "\tnewRow=" << newRow;
+        qCDebug(kpLogDialogs) << "\tnewRow=" << newRow;
     #endif
         Q_ASSERT (newRow < d->fieldsTableWidget->rowCount ());
 
         int newCol = d->fieldsTableWidget->currentColumn ();
     #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-        kDebug () << "\tnewCol=" << newCol;
+        qCDebug(kpLogDialogs) << "\tnewCol=" << newCol;
     #endif
         if (newCol != 0 && newCol != 1)
         {
             newCol = 0;
         #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-            kDebug () << "\t\tcorrecting to " << newCol;
+            qCDebug(kpLogDialogs) << "\t\tcorrecting to " << newCol;
         #endif
         }
 
@@ -613,12 +613,12 @@ void kpDocumentMetaInfoDialog::fieldsDeleteRow (int r)
 void kpDocumentMetaInfoDialog::enableFieldsDeleteRowButtonIfShould ()
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::enableFieldsDeleteRowButtonIfShould()";
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::enableFieldsDeleteRowButtonIfShould()";
 #endif
 
     const int r = d->fieldsTableWidget->currentRow ();
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "\tr=" << r;
+    qCDebug(kpLogDialogs) << "\tr=" << r;
 #endif
 
     d->fieldsDeleteRowButton->setEnabled (isFieldsRowDeleteable (r));
@@ -630,7 +630,7 @@ void kpDocumentMetaInfoDialog::slotFieldsCurrentCellChanged (int row, int col,
         int oldRow, int oldCol)
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::slotFieldsCurrentCellChanged("
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsCurrentCellChanged("
               << "row=" << row << ",col=" << col
               << ",oldRow=" << oldRow << ",oldCol=" << oldCol
               << ")" << endl;
@@ -650,25 +650,25 @@ void kpDocumentMetaInfoDialog::slotFieldsCurrentCellChanged (int row, int col,
 void kpDocumentMetaInfoDialog::slotFieldsItemChanged (QTableWidgetItem *it)
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::slotFieldsItemChanged("
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsItemChanged("
               << "item=" << it << ") rows=" << d->fieldsTableWidget->rowCount ()
               << endl;
 #endif
 
     const int r = d->fieldsTableWidget->row (it);
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "\tr=" << r;
+    qCDebug(kpLogDialogs) << "\tr=" << r;
 #endif
     Q_ASSERT (r >= 0 && r < d->fieldsTableWidget->rowCount ());
 
     const QString key = d->fieldsTableWidget->item (r, 0)->text ();
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << " key='" << key << "'";
+    qCDebug(kpLogDialogs) << " key='" << key << "'";
 #endif
 
     const QString value = d->fieldsTableWidget->item (r, 1)->text ();
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << " value='" << value << "'";
+    qCDebug(kpLogDialogs) << " value='" << value << "'";
 #endif
 
     // At the last row?
@@ -711,13 +711,13 @@ void kpDocumentMetaInfoDialog::slotFieldsItemChanged (QTableWidgetItem *it)
 void kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked ()
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked()"
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked()"
               << endl;
 #endif
 
     const int r = d->fieldsTableWidget->currentRow ();
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "\tr=" << r;
+    qCDebug(kpLogDialogs) << "\tr=" << r;
 #endif
 
     // (if no row is selected, r = -1)
@@ -734,13 +734,13 @@ void kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked ()
 void kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked ()
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked()"
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked()"
               << endl;
 #endif
 
     const int r = d->fieldsTableWidget->currentRow ();
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    kDebug () << "\tr=" << r;
+    qCDebug(kpLogDialogs) << "\tr=" << r;
 #endif
 
     Q_ASSERT (isFieldsRowDeleteable (r));
