@@ -33,7 +33,7 @@
 
 #include <qimage.h>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "pixmapfx/kpPixmapFX.h"
 
