@@ -41,6 +41,7 @@
 #include <qsize.h>
 #include <QPrinter>
 #include <QPrintDialog>
+#include <QScreen>
 #include <QApplication>
 #include <QTimer>
 #include <QLabel>
@@ -49,26 +50,24 @@
 #include <QImageReader>
 #include <QImageWriter>
 #include <QMimeDatabase>
-#include <QScreen>
+#include <QPrintPreviewDialog>
 
 #include <kactioncollection.h>
-#include <kconfig.h>
+#include <KSharedConfig>
 #include <kconfiggroup.h>
-#include "kpLogCategories.h"
 #include <KPluralHandlingSpinBox>
 #include <kfiledialog.h>
 #include <kiconloader.h>
 #include <kio/netaccess.h>
-#include <klocale.h>
 #include <kmessagebox.h>
 #include <krecentfilesaction.h>
 #include <kstandardshortcut.h>
 #include <kstandardaction.h>
 #include <ktoolinvocation.h>
+#include <KLocalizedString>
 #include <kdeprintdialog.h>
-#include <kprintpreview.h>
-#include <kurlcombobox.h>
 
+#include "kpLogCategories.h"
 #include "commands/kpCommandHistory.h"
 #include "kpDefs.h"
 #include "document/kpDocument.h"
@@ -1165,7 +1164,14 @@ void kpMainWindow::sendDocumentNameToPrinter (QPrinter *printer)
     }
 }
 
+//--------------------------------------------------------------------------------
 
+void kpMainWindow::sendPreviewToPrinter(QPrinter *printer)
+{
+  sendImageToPrinter(printer, false);
+}
+
+//--------------------------------------------------------------------------------
 // private
 void kpMainWindow::sendImageToPrinter (QPrinter *printer,
         bool showPrinterSetupDialog)
@@ -1390,11 +1396,8 @@ void kpMainWindow::slotPrintPreview ()
 {
     toolEndShape ();
 
-    QPrinter printer;
-
-    KPrintPreview printPreview (&printer);
-
-    sendImageToPrinter (&printer, false/*don't showPrinterSetupDialog*/);
+    QPrintPreviewDialog printPreview(this);
+    connect(&printPreview, &QPrintPreviewDialog::paintRequested, this, &kpMainWindow::sendPreviewToPrinter);
 
     printPreview.exec ();
 }
