@@ -36,9 +36,6 @@
 #include <qstring.h>
 
 #include "kpLogCategories.h"
-#include <klocale.h>
-#include <KSqueezedTextLabel>
-
 #include "kpDefs.h"
 #include "document/kpDocument.h"
 #include "tools/kpTool.h"
@@ -46,6 +43,9 @@
 #include "kpViewScrollableContainer.h"
 #include "views/kpZoomedView.h"
 
+#include <KSqueezedTextLabel>
+#include <KLocalizedString>
+
 //---------------------------------------------------------------------
 
 // private
