@@ -32,12 +32,11 @@
 #include <QActionGroup>
 #include <qlist.h>
 
-#include <kapplication.h>
 #include <kactioncollection.h>
-#include <kconfig.h>
+#include <KSharedConfig>
 #include <kconfiggroup.h>
 #include "kpLogCategories.h"
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "widgets/toolbars/kpColorToolBar.h"
 #include "commands/kpCommandHistory.h"
@@ -643,7 +642,7 @@ void kpMainWindow::slotEndedDocResize (const QSize &size)
                     " responsiveness and cause other application resource"
                     " problems.</p>"
 
-                    "<p>Are you sure want to resize the"
+                    "<p>Are you sure you want to resize the"
                     " image?</p></qt>",
                   d->docResizeWidth,
                   d->docResizeHeight),
