@@ -36,7 +36,7 @@
 #include <qpainter.h>
 
 #include "kpLogCategories.h"
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "imagelib/kpColor.h"
 #include "commands/kpCommandHistory.h"
