@@ -29,13 +29,13 @@
 #define DEBUG_KP_COLOR_PALETTE 0
 
 
-#include <kpColorPalette.h>
+#include "kpColorPalette.h"
+
+#include "kpColorCells.h"
+#include "kpTransparentColorCell.h"
 
 #include <QBoxLayout>
 
-#include <kpColorCells.h>
-#include <kpTransparentColorCell.h>
-
 //---------------------------------------------------------------------
 
 struct kpColorPalettePrivate
@@ -122,4 +122,3 @@ kpColorCells *kpColorPalette::colorCells () const
 
 //---------------------------------------------------------------------
 
-#include <kpColorPalette.moc>
