@@ -34,7 +34,7 @@
 #include <qframe.h>
 #include <qwidget.h>
 
-#include <kpColor.h>
+#include "imagelib/kpColor.h"
 
 
 class QBoxLayout;
@@ -108,8 +108,8 @@ protected:
     // Eat color drops (which are usually accidental drags from one of our
     // child widgets) to prevent them from being pasted as text in the
     // main window (by kpMainWindow::dropEvent()).
-    virtual void dragEnterEvent (QDragEnterEvent *e);
-    virtual void dragMoveEvent (QDragMoveEvent *e);
+    void dragEnterEvent (QDragEnterEvent *e) Q_DECL_OVERRIDE;
+    void dragMoveEvent (QDragMoveEvent *e) Q_DECL_OVERRIDE;
 
 private:
     void adjustToOrientation (Qt::Orientation o);
