@@ -72,7 +72,7 @@ signals:
     void fillStyleChanged (kpToolWidgetFillStyle::FillStyle fillStyle);
 
 protected slots:
-    virtual bool setSelected (int row, int col, bool saveAsDefault);
+    bool setSelected (int row, int col, bool saveAsDefault) Q_DECL_OVERRIDE;
 };
 
 
